<?php
namespace BlogFromBWD;

define( "BWDBP_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class CallBlogFromBWD {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdbp_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdbp_admin_editor_scripts_as_a_module' ], 10, 2 );
	}
	public function bwdbp_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdbp_the_blog_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/post-grid-w.php' );
	}

	public function bwdbp_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDBPBlog() );
	}

	// Register Category
	function bwdbp_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'creative-blog-post-category',
			[
				'title' => esc_html__( 'BWD Post Grid', 'creative-blog-post' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdbp_all_assets_for_the_public(){
		$all_css_js_file = array(
            'bwdbp_blog_responsive_column' => array('bwdbp_path_define'=>'https://bwd-elementor-addons-pro.netlify.app/responsive-column.css'),
            'bwdbp_blog_blog_main' => array('bwdbp_path_define'=>'https://bwd-elementor-addons-pro.netlify.app/bwd-post-grid.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbp_path_define'], null, '2.1', 'all');
        }
	}

	public function bwdbp_all_assets_for_the_admin_dash(){
		$all_css_js_file = array(
            'bwdbp_blog_admin_dashboard_css' => array('bwdbp_path_admin_dash'=>BWDBP_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbp_path_admin_dash'], null, '2.1', 'all');
        }
	}

	// For tags
	function the_tags( $before = null, $sep = ', ', $after = '' ) {
		if ( null === $before ) {
			$before = esc_html__( 'Tags:- ' );
		}
		$the_tags = get_the_tag_list( $before, $sep, $after );
		if ( ! is_wp_error( $the_tags ) ) {
			echo $the_tags;
		}
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdbp_all_assets_for_the_public']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdbp_add_elementor_widget_categories' ] );

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdbp_all_assets_for_the_admin_dash']);

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdbp_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdbp_admin_editor_scripts' ] );
	}
}

// Instantiate Plugin Class
CallBlogFromBWD::instance();